@@ -145,8 +145,7 @@ T toNumber(const ByteVector &v, size_t offset, bool mostSignificantByteFirst)
 
   if(swap)
     return Utils::byteSwap(tmp);
-  else
-    return tmp;
+  return tmp;
 }
 
 template <class T>
@@ -242,14 +241,12 @@ long double toFloat80(const ByteVector &v, size_t offset)
       debug("toFloat80() - can't handle the infinity or NaN. Returning 0.");
       return 0.0;
     }
-    else
-      val = ::ldexp(static_cast<long double>(fraction), exponent - 16383 - 63);
+    val = ::ldexp(static_cast<long double>(fraction), exponent - 16383 - 63);
   }
 
   if(negative)
     return -val;
-  else
-    return val;
+  return val;
 }
 
 class ByteVector::ByteVectorPrivate
@@ -300,8 +297,7 @@ ByteVector ByteVector::fromCString(const char *s, unsigned int length)
 {
   if(length == 0xffffffff)
     return ByteVector(s, static_cast<unsigned int>(::strlen(s)));
-  else
-    return ByteVector(s, length);
+  return ByteVector(s, length);
 }
 
 ByteVector ByteVector::fromUInt(unsigned int value, bool mostSignificantByteFirst)
@@ -443,8 +439,7 @@ int ByteVector::rfind(const ByteVector &pattern, unsigned int offset, int byteAl
 
   if(pos == -1)
     return -1;
-  else
-    return size() - pos - pattern.size();
+  return size() - pos - pattern.size();
 }
 
 bool ByteVector::containsAt(const ByteVector &pattern, unsigned int offset, unsigned int patternOffset, unsigned int patternLength) const
@@ -843,8 +838,7 @@ bool ByteVector::operator<(const ByteVector &v) const
   const int result = ::memcmp(data(), v.data(), std::min(size(), v.size()));
   if(result != 0)
     return result < 0;
-  else
-    return size() < v.size();
+  return size() < v.size();
 }
 
 bool ByteVector::operator>(const ByteVector &v) const
@@ -925,8 +919,8 @@ ByteVector ByteVector::fromBase64(const ByteVector & input)
 
   ByteVector output(len);
 
-  const unsigned char * src = (const unsigned char*) input.data();
-  unsigned char *       dst = (unsigned char*) output.data();
+  const unsigned char * src = reinterpret_cast<const unsigned char*>(input.data());
+  unsigned char *       dst = reinterpret_cast<unsigned char*>(output.data());
 
   while(4 <= len) {
 
@@ -976,7 +970,7 @@ ByteVector ByteVector::fromBase64(const ByteVector & input)
 
   // Only return output if we processed all bytes
   if(len == 0) {
-    output.resize(static_cast<unsigned int>(dst - (unsigned char*) output.data()));
+    output.resize(static_cast<unsigned int>(dst - reinterpret_cast<unsigned char*>(output.data())));
     return output;
   }
   return ByteVector();
@@ -1030,7 +1024,7 @@ void ByteVector::detach()
       ByteVector().swap(*this);
   }
 }
-}
+}  // namespace TagLib
 
 ////////////////////////////////////////////////////////////////////////////////
 // related functions
